/*
 *	     Module : lcd.c
 *              pjt : all
 *      description : drives LCD on PM990x evm,
 *                    uses ROM LUT and hardware SPI.
 *              ver : 1.2.1
 *	         log:
 *		1.2.1 _df 7-10-2002  finally fixed kVarh icon
 *		1.2   _df 01-10-2002 changed to alpha-numeric
 *		1.1   _df 28-10-2001 changes for native SPI
 *		1.0   _df 25-10-2001 init coding
 */

#include "segments.h"				//character LUT and constants 
#include "sa8807.c"				//SA8807 Ctrl


void lcd_2_RAM(void)
{
 uchar i;

 if(!oLCD) lcd_addr();				//wake SA8807 
 for(i=0;i<MAX_DIGIT;i++) lcd_data(seg[i]);	//download seg[] to SA8807
 lcd_reset();					//display seg[]
}

void lcd_clrbuffer()
{
 uchar i;
  for(i=0;i<=MAX_DIGIT;i++) seg[i]=SPC_SEG;
}


void lcd_clear(void) 				//write spaces to display buffer and display it 
{
 lcd_clrbuffer();
 lcd_2_RAM();
}

void lcd_icon(uchar command)		//to do icons simultaneously call fcn repetively
{
  switch(command)
   {
    case OFF:	 seg[0]   =0x0;
		 seg[9]   =0x0;
		 seg[10]  =0x0;
    		 seg[11]  =0x0;		
	   	 break;
    case PHASE1: seg[10] ^=0x40; 		//^ allows selective switching off
	   	 break;
    case PHASE2: seg[10] ^=0x80;
	   	 break;
    case PHASE3: seg[9]  ^=0x80;
	   	 break;
    case COS:    seg[0]  ^=0x10;
	   	 break;
    case VOLT:   seg[9]  ^=0x01;
	   	 break;
    case HZ:     seg[10] ^=0x20;
	   	 break;
    case AMP:    seg[9]  ^=0x02;
	   	 break;
    case KVAR:   seg[9]  ^=0x0f; //Var=0x07 and Varh =0x0f
     		 seg[10] ^=0x10; //k= 0x10
	   	 break;
    case KWH:    seg[10] ^=0x0b;
	   	 break;
   }
  lcd_2_RAM();
}

void lcd(char *buffer, uchar check)
{
 uchar index,
       one_char,
       dp_on,					//decimal point on?
       offset; 					//offset into LUT

  lcd_clear(); 					//init lcd
  index=DISP;
  dp_on=0; 					//dp off

  do
   {
    check--;
    one_char=buffer[check];

    if(one_char>DECIDER) offset=ASCII+0x7;	//its a letter
     else offset=ASCII; 			//its a number

    switch(one_char) 				//convert character to 7segment
     {
      case D_POINT:
		dp_on=(index+check);
		break;
      case MINUS:
		seg[index]=MINUS_SEG;
		break;
      case SPACE:
		seg[index]=SPC_SEG;
		break;
      	 default:
		seg[index]=Character[one_char-offset];
		break;
     }
    if(dp_on >(index+check)) 			//tst if dp must be added & do it
     {
      seg[index]|=DP_SEG;
      dp_on=0;
     }
    if(one_char != D_POINT) index--;
   }while(check);
  lcd_2_RAM();  				//--- tx converted data to LCD ---
}
//-------------------------------EoF-----------------------------
