/*
 *	      File : sa9903.h
 *	       Pjt : sa9903.pjt
 *
 *     description : Project's header file
 *	  compiler : Hi Tech C v8.00PL1
 *	 processor : 16F876-20
 *	      xtal : 20 MHz
 *             ver : 1.0
 *	        log:
 *		     1.0 _df 29-09-2002 init coding
 *
 */

#include <pic.h>
#include "always.h" 	//some short-cuts


// -------------------------- set up 4 target uCtrler -------------------------
#asm
processor       16F876					//uC type
#endasm
#define FOSC	(20000000L)				//uC's crystal freq, 20MHz.
__CONFIG(0x3f72);					//!wdt,!codeProt,!LVP, rest is on


// -------------------------- constants ---------------------------------------
#define THRES		12520.  			//5000 p/kWh
#define ENG_PULSE	0.001

#define IO_BITS_A       0b110000                     	//for TRISA
#define IO_BITS_B       0b11110001                   	//for TRISB,top for intr on change
#define IO_BITS_C       0b00010000                   	//for TRISC

#define KEY_MASK	0xf0				//1111 0000, only intersted in top nibble
#define ENTER		0x01
#define UP		0x03
#define DOWN		0x04

#define SETUP_CCP1	0x0b
#define SETUP_TMR1	0x01
#define LOAD_CCP1H	0xc3
#define LOAD_CCP1L	0x4f

//10ms constants:-
#define PULSE	  1 					//# of ticks for 10ms LED pulse width
#define SECOND	100					//# of ticks for 1sec LCD update rate

//port definitions
static bit	oA_LED	@ PB(PORTA,0);			//active    rate_LED
static bit	oR_LED	@ PB(PORTA,1);			//re-active rate_LED

static bit	oLCD	@ PB(PORTC,0);			//LCD's         chip select
static bit	oMTR	@ PB(PORTC,1);			//metering ic's chip select
static bit      oMEM    @ PB(PORTC,2);			//e^2's         chip select

static bit      iENT	@ PB(PORTB,5);			//Enter key
static bit      iDWN	@ PB(PORTB,6);			//Down  key
static bit      iUP	@ PB(PORTB,7);			//Up    key


// -------------------------- globals(to enable 'Banking') -------------------- 
/*bank0*/
uchar			tick_count,		//for counting tmr0 ticks, repeats (0..100)
        		t_LED,     		//LED pulsewidth counter, repeats  (x..0)
			key,			//key buffer (Up,Down,Enter)
			first[2];		//indicates 1st sample


static bit		aLED,			//active rate-LED status
			rLED,			//re-active rate-LED status
			sample,			//indicates when to sample
			display, 		//LCD ctrl
			dwn_menu, ent_menu;	//menu ctrl

/*bank1*/
bank1 volatile long	new_val,		//present register value 
			delta_val,		//difference between consecutive readings
			prev_val[2],		//previous register value
			accumulator[2],		//accumulated energy
			threshold[2],		//energy threshold
			test;			//temp storage for labs() use
const enum{ACT,REACT};

bank1 sint  		volt,			//supply voltage
			freq;			//supply frequency

bank1 float 		energy[2],		//energy display on LCD
   			lcd_temp;		//for displaying on LCD

bank1 float CAL[2]={				//calibration factors
		    +0.0, //active
		    +0.0, //reactive
                   };
bank1 uchar		tempB,			//for RBIF 
 			num_char,		//for displaying on LCD
        		disp_buff[8];		//       "


// -------------------------- Project's function prototypes ------------------
//SA9903.c
void init(void);
long labs(long);
long wrap(long);
void process_data(void);
void boot_scrn(void);

//sa990x.c
void wait_spi(void);
void poll_spi(void);
void tx_addr(uchar);
long acquire(uchar);

#include "sa990x.c" 	//communication with SA9903
#include "lcd.c"	//lcd ctrl
#include "prompts.c"	//general prompts
/* EoF mtb.h */
