/*
 *	     Module : SA990x.c
 *              pjt : present spi-based devices
 *      description : Re-use of 9904 project's module, 
 *                    utilises PIC's native SPI hardware
 *
 *              ver : 1.0.1
 *	         log:
 *			1.0.1 _df 21-11-2001 moved com_spi.c's code to this module
 *			1.0   _df 26-10-2001 init coding
 *
 */

//macros
#define  cs_on()	oMTR=ON 	//lift chip select
#define  cs_off()	oMTR=OFF	//drop chip select

//spi globals
 uchar 		discard;		//used to flush SSPBUF


void wait_spi(void)			//wait for completion
{
 do
  {

  }while(!STAT_BF);			//wait until SSPIF raised, i.e. tx completed
 STAT_BF=OFF;				//rst flag
}

void poll_spi(void)			//gen clk for the data
{
 if(STAT_BF)
  {
   discard=SSPBUF;			//trashcan
   STAT_BF=OFF;				//rst flag
  }
 SSPBUF=0x00;				//tx dummy
 wait_spi();				//confirmation
}

void tx_addr(uchar address)		
{
   if(!oMTR) cs_on(); 			//chip's select high
   SSPBUF= 0x01;			//1st bit of read command <0000 0001>
   wait_spi();
   if(STAT_BF) discard=SSPBUF;		//trashcan  
   SSPBUF = (address|0x80);		//tx 10 of the read command <10A5A4 A3A2A1A0>
   wait_spi();
   if(STAT_BF) discard=SSPBUF;		//trashcan
}

#define LIMIT 0xFFFFFF 			//upperlimit for 24 bits 

long acquire(uchar address)		//read 24bit register
{
 long	input;				//the spi return variable
 uchar 	in[3],				//buffer for received bytes
    	i,k,				//counters
    	byte_mask;			//as it says
 ulong  word_mask;			// ditto


    tx_addr(address);			//tx register's address

//----- rx bytes --------------
// <<0,1,2 -> MSB ... LSB>>
//-----------------------------
    for(i=0;i<3;i++)
     {
      poll_spi();			//clock a byte into SSPBUF
      if(STAT_BF) in[i]=SSPBUF;		//if byte received read it
     }
    if(oMTR) cs_off();			//no longer accessing chip

//----- construct 24bit variable -------------- 
// input  = ((((in[0]<<8)|in[1])<<8)|(in[2]))   
//--------------------------------------------- 
    input=0x0;
    word_mask=1;
    i=3;
    do
     {
      i--;
      byte_mask=1;
      for(k=0;k<8;k++)
       {
        if(in[i] & byte_mask) input|=word_mask;
        byte_mask <<= 1; //roll mask 1bit left
        word_mask <<= 1; //       ditto
       }
     }while(i);//lsb to msb

  input &= LIMIT;
 return(input);
}
//-------------------------------EoF-----------------------------

