/*
 *	     Module : segments.h
 *              pjt : all
 *      description : character mapping for LCD on PM990x evm, 
 *                    supports 
 * 			letters A to Z, numbers 0 to 9, 
 * 			space, minus and decimal point.
 *
 *              ver : 1.2
 *
 *	         log:
 *		1.2 _df 01-10-2002 added constant DECIDER and a to z to LUT.
 *		1.1 _df 28-10-2001 changes for native SPI
 *		1.0 _df 25-10-2001 init coding
 */

//ifdef flags
//#define DBG_LCD						//debuging 

//constants

const enum{PHASE1=1,PHASE2,PHASE3,COS,VOLT,HZ,AMP,KVAR,KWH};	//lcd icons

#define MAX_DIGIT	12
#define DISP		8				//number of digits to display

#define	ASCII		0x30				//Ascii offset to decimal
#define DECIDER		0x39				//number or letter?
#define SPACE		0x20				//Ascii value of space
#define D_POINT		0x2e				//Ascii value of decimal point
#define MINUS		0x2d				//Ascii value of minus

#define SPC_SEG		0x0				//switch all segments off
#define MINUS_SEG	0x20				//-
#define DP_SEG		0x08				//.


//ROM Look Up Table for 7-segment characters 
//	         a
//	       -----
//	     f|     |b
//	      |  g  |
//	       ----- 
//	      |	    | 
//	     e|     |c
//	       -----   	.h
//	   	d
//
// As example to calculate 7-segment code for 0 use:
//		degf hcba
//		1101 0111  
//	     => 0xd7
//

const	unsigned char Character[36] = {
					0xd7,		// 0
					0x06,		// 1
					0xe3,		// 2
					0xa7,   	// 3
					0x36,   	// 4
					0xb5,   	// 5
					0xf5,		// 6
					0x07,		// 7
					0xf7,		// 8
					0xb7, 		// 9
					0x77, 		// A
					0xf4, 		// B
					0xe0, 		// C
					0xe6, 		// D
					0xf1, 		// E
					0x71, 		// F
					0xb7, 		// G
					0x74, 		// H
					0x40, 		// I
					0x86, 		// J
					0x72, 		// K	-> don't use, ugly
					0xd0, 		// L
					0x64, 		// M	-> use n n
					0x64, 		// N
					0xe4, 		// O
					0x73, 		// P
					0xd7, 		// Q	-> don't use, ugly 
					0x60, 		// R
					0xb5, 		// S
					0xf0, 		// T
					0xc4, 		// U
					0xc4, 		// V
					0xc4, 		// W	-> use u u 
					0x76, 		// X	-> don't use, ugly
					0x36, 		// Y	-> don't use, ugly
					0xe3, 		// Z
				      };

// Global variables
#ifdef DBG_LCD
static bit been_here;		 			//bank0 bitfield
#endif
bank1 char seg[MAX_DIGIT];	 			//LCD 'global' buffer



//-------------------- fcn prototypes ---------------

// lcd.c
void lcd_2_RAM(void);
void lcd_clrbuffer(void);
void lcd_clear(void);
void lcd_icon(uchar);
void lcd(char *, uchar);

// sa8807.c
void lcd_addr(void);
void lcd_data(uchar);
void lcd_reset(void);
//-------------------------------EoF-----------------------------
